@@ -47,10 +47,12 @@ BASE_EXTERNAL_IO_EXCEPTION_METRIC = 'external_io_exception_type'
 BASE_FUNCTION_EXCEPTION_METRIC = 'function_exception_type'
 BASE_FUNCTION_LATENCY_GAUGE_METRIC = 'function_duration_ms_total'
 
+BASE_BYTES_METRIC = 'bytes_size'
+
 METRIC_NAME_SEPERATOR = '_'
 METRIC_LABEL_SEPERATOR = '.'
 
-HTTP_REQUEST_STATUS_CODE_STRING_OPTIONS = ['2xx', '3xx', '4xx', '5xx']
+HTTP_REQUEST_STATUS_CODE_OPTIONS = range(200,599)
 FUNCTION_STATUS_VALUES = ['success', 'error']
 
 def prefix_metric_name(prefix, metric_name, seperator=METRIC_NAME_SEPERATOR):
@@ -104,6 +106,10 @@ def create_external_service_latency_gauge_metric_name(metric_prefix_app_name, me
     metric_name = prefix_metric_name(metric_prefix_app_name, metric_name)
     return metric_name
 
+def create_bytes_metric_name(metric_prefix_app_name,  metric_name=BASE_BYTES_METRIC):
+    metric_name = prefix_metric_name(metric_prefix_app_name, metric_name)
+    return metric_name
+
 def create_http_request_metrics(status_code, duration_ms, metric_prefix_app_name, exception_type_class=None):
     """
         Pushes duration metrics for http requests. Creates three types of metrics:
@@ -113,24 +119,25 @@ def create_http_request_metrics(status_code, duration_ms, metric_prefix_app_name
 
         Attributes:
         -----------
-        status_code str: Can only be one out of ['2xx', '3xx', '4xx','5xx']
+        status_code int: Can only be valid http status code (200, 599)
         duartion_ms float: Time taken for request in milliseconds
         metric_prefix_app_name str: This string will be added to the start of each metric generated.
 
         Returns tuple: (<histogram_metric_name>, <guage_metric_name>, <exception_metric_name>)
                         exception_metric_name is None is status code is other than 5xx and no exception_type_class is provided
     """
-    if status_code not in HTTP_REQUEST_STATUS_CODE_STRING_OPTIONS:
-        raise ValueError('status_code can only be one of {}'.format(', '.join(HTTP_REQUEST_STATUS_CODE_STRING_OPTIONS)))
+    if status_code not in HTTP_REQUEST_STATUS_CODE_OPTIONS:
+        raise ValueError('status_code can only be one of {}'.format(', ',join(HTTP_REQUEST_STATUS_CODE_OPTIONS)))
 
     exception_metric = None
-    if status_code == HTTP_REQUEST_STATUS_CODE_STRING_OPTIONS[3]:
+    if status_code >= 500:
+        status_code = str(status_code)
         if  exception_type_class:
             exception_metric = create_http_requests_exception_metric_name(metric_prefix_app_name)
             exception_metric = add_label_to_metric_name(exception_type_class, exception_metric)
             statsd_client.incr(exception_metric)
             logger.debug('Incremented metric {}'.format(exception_metric))
-
+    status_code = str(status_code)
     hist_request_duration = create_http_request_latency_histogram_metric(metric_prefix_app_name)
     hist_request_duration = add_label_to_metric_name(status_code, hist_request_duration)
     statsd_client.timing(hist_request_duration, duration_ms)
@@ -148,8 +155,10 @@ def create_http_request_counter_metric(status_code, metric_prefix_app_name):
     """
         Increments a simple counter metric to track the number of requests made.
     """
-    if status_code not in HTTP_REQUEST_STATUS_CODE_STRING_OPTIONS:
-        raise ValueError('status_code can only be one of {}'.format(', '.join(HTTP_REQUEST_STATUS_CODE_STRING_OPTIONS)))
+    if status_code not in HTTP_REQUEST_STATUS_CODE_OPTIONS:
+        raise ValueError('status_code can only be one of {}'.format(', ',join(HTTP_REQUEST_STATUS_CODE_OPTIONS)))
+
+    status_code = str(status_code)
     request_counter_metric = create_http_request_counter_metric_name(metric_prefix_app_name)
     request_counter_metric = add_label_to_metric_name(status_code, request_counter_metric)
     statsd_client.incr(request_counter_metric)
@@ -244,3 +253,21 @@ def create_external_service_duration_metrics(status, duration_ms, metric_prefix_
     logger.debug('Created gauge external service duration metric {} with value {}'.format(service_duration_gauge_metric, duration_ms))
 
     return hist_metric, service_duration_gauge_metric, exception_metric
+
+def create_bytes_metric(metric_prefix_app_name, size_in_bytes, name_label):
+    """
+        Function to push bytes metric.
+        Attributes:
+        ----------
+        name_label: label to identify which component/module/function etc is being measured. <b> Cannot contain special charaters except _ .
+
+    """
+    metric_name = create_bytes_metric_name(metric_prefix_app_name)
+    metric_name = add_label_to_metric_name(name_label, metric_name)
+
+    statsd_client.gauge(metric_name, size_in_bytes)
+    logger.debug('Created gauge bytes metric {} with value {}'.format(metric_name, size_in_bytes))
+
+    return metric_name
+
+
